/** @author Jan Abel 
 * 4belJan@googlemail.com 
 */

/**
 * Implementiert den Koch als eigenständigen Thread.
 * 
 * @author Sebastian Flothow (sebastian@flothow.de)
 */
public class Cook extends Thread {
	private Pot pot;
	private final static int SERVINGS_PER_BATCH = 5;
	
	/**
	 * Erzeugt einen Koch, der den angegebenen Topf fortlaufend füllt.
	 * 
	 * @param pot Topf, den der Koch füllen soll.
	 */
	public Cook(Pot pot) {
		this.pot = pot;
	}

	
	/**
	 * Füllt fortlaufend den Topf. Falls eine Exception auftritt wird diese auf stderr
	 * ausgegeben und der Thread beendet.
	 */
	@Override
	public void run() {
		try {
			while (true) {
				synchronized (pot) {
					// verhindere spurious wakeups
					while(pot.getContent() != 0) {
						try {
							// koch warten lassen bis wieder aufgefüllt werden muss
							pot.wait();
						} catch (InterruptedException e) {
							System.err.println("Koch wait failed\n" + e);
						}
					}
					System.out.println("Koch füllt " + SERVINGS_PER_BATCH + " Portionen in den Topf");
					pot.putServings(SERVINGS_PER_BATCH);
					// wecke savages
					pot.notifyAll();
				}
			}
		} catch (Exception e) {
			System.err.print("Koch: ");
			e.printStackTrace();
		}
	}
}
